This helper function checks whether a given file or directory path appears to be located inside a Dropbox-synced folder. It is used to warn users about potential file-locking issues when running BEAST2 from Dropbox-backed locations.
This helper function checks whether a given file or directory path appears to be located inside a Dropbox-synced folder. It is used to warn users about potential file-locking issues when running BEAST2 from Dropbox-backed locations.